@@ -1,14 +1,10 @@
-from openride import PointCloud
-from openride.core.point import Point
-from openride.core.rotation import Rotation
-from openride.core.transform import Transform
+from openride import PointCloud, Point, Rotation, Transform
 from openride.test import get_pytest_benchmark
 
 import numpy as np
 import pytest
 
 
-
 pytest_benchmark = get_pytest_benchmark(group="core.collections.point_cloud")
 
 
@@ -57,7 +53,7 @@ def test_getitem(benchmark):
 @pytest_benchmark
 def test_transform(benchmark):
     pc = PointCloud([Point() for _ in range(10000)])
-    tf = Transform(Point(1), Rotation(0,0,np.pi))
+    tf = Transform(Point(1), Rotation(0, 0, np.pi))
     pc = benchmark(pc.transform, tf)
     assert pytest.approx(pc[0].x) == -1
 
@@ -65,6 +61,5 @@ def test_transform(benchmark):
 def test_get_point_cloud():
     pc = PointCloud([Point(), Point()])
     xyz = pc.get_point_cloud()
-    assert xyz.shape == (2,3)
+    assert xyz.shape == (2, 3)
     assert np.all(xyz == 0.0)
-    
\ No newline at end of file
